@@ -320,7 +320,7 @@ ExtendedProcesses::ExtendedProcesses(QObject *parent)
     ioniceLevelSensor->setUnit(KSysGuard::UnitNone);
     d->m_coreAttributes << ioniceLevelSensor;
 
-    auto vmSizeSensor = new ProcessSensor<qlonglong>(this, QStringLiteral("vmSize"), i18n("VM Size"), &KSysGuard::Process::vmSize, KSysGuard::Process::VmSize);
+    auto vmSizeSensor = new ProcessSensor<qlonglong>(this, QStringLiteral("vmSize"), i18n("VM Size"), &KSysGuard::Process::vmSize, KSysGuard::Process::Memory);
     vmSizeSensor->setUnit(KSysGuard::UnitKiloByte);
     vmSizeSensor->setMin(0);
     vmSizeSensor->setMax(totalPhysicalMemory());
@@ -330,7 +330,7 @@ ExtendedProcesses::ExtendedProcesses(QObject *parent)
     d->m_coreAttributes << vmSizeSensor;
 
     auto vmRSSSensor =
-        new ProcessSensor<qlonglong>(this, QStringLiteral("vmRSS"), i18n("Resident Memory Usage"), &KSysGuard::Process::vmRSS, KSysGuard::Process::VmRSS);
+        new ProcessSensor<qlonglong>(this, QStringLiteral("vmRSS"), i18n("Resident Memory Usage"), &KSysGuard::Process::vmRSS, KSysGuard::Process::Memory);
     vmRSSSensor->setUnit(KSysGuard::UnitKiloByte);
     vmRSSSensor->setShortName(i18n("Resident"));
     vmRSSSensor->setMin(0);
@@ -340,7 +340,7 @@ ExtendedProcesses::ExtendedProcesses(QObject *parent)
     d->m_coreAttributes << vmRSSSensor;
 
     auto vmURSSSensor =
-        new ProcessSensor<qlonglong>(this, QStringLiteral("vmURSS"), i18n("Private Memory Usage"), &KSysGuard::Process::vmURSS, KSysGuard::Process::VmURSS);
+        new ProcessSensor<qlonglong>(this, QStringLiteral("vmURSS"), i18n("Private Memory Usage"), &KSysGuard::Process::vmURSS, KSysGuard::Process::Memory);
     vmURSSSensor->setUnit(KSysGuard::UnitKiloByte);
     vmURSSSensor->setShortName(i18n("Private"));
     vmURSSSensor->setMin(0);
@@ -360,7 +360,7 @@ ExtendedProcesses::ExtendedProcesses(QObject *parent)
             }
             return (qlonglong)(p->vmRSS() - p->vmURSS());
         },
-        KSysGuard::Process::VmRSS);
+        KSysGuard::Process::Memory);
     d->m_coreAttributes << sharedMemorySensor;
     sharedMemorySensor->setShortName(i18n("Shared"));
     sharedMemorySensor->setDescription(
@@ -370,17 +370,48 @@ ExtendedProcesses::ExtendedProcesses(QObject *parent)
     sharedMemorySensor->setMin(0);
     sharedMemorySensor->setMax(totalPhysicalMemory());
 
-    auto vmPSSSensor = new ProcessSensor<qlonglong>(this, QStringLiteral("vmPSS"), i18n("Memory Usage"), &KSysGuard::Process::vmPSS, KSysGuard::Process::VmPSS);
-    vmPSSSensor->setShortName(i18n("Memory"));
+    auto vmPSSSensor = new ProcessSensor<qlonglong>(this,
+                                                    QStringLiteral("vmPSS"),
+                                                    i18nc("@title:column", "Proportional Memory Usage"),
+                                                    &KSysGuard::Process::vmPSS,
+                                                    KSysGuard::Process::Memory);
+    vmPSSSensor->setShortName(i18nc("@title:column", "Proportional"));
     vmPSSSensor->setUnit(KSysGuard::UnitKiloByte);
     vmPSSSensor->setMin(0);
     vmPSSSensor->setMax(totalPhysicalMemory());
     vmPSSSensor->setRequiredUpdateFlags(Processes::Smaps);
     vmPSSSensor->setDescription(
-        i18n("This is an approximation of the real amount of physical memory that this process is using. It is calculated by dividing the process' shared "
-             "memory usage by the amount of processes sharing that memory, then adding the process' private memory."));
+        i18nc("@info:tooltip",
+              "This is an approximation of the real amount of physical memory that this process is using. It is calculated by dividing this process' shared "
+              "memory usage by the number of processes sharing that memory, then adding this process' private memory. This value may not be available for "
+              "certain processes."));
     d->m_coreAttributes << vmPSSSensor;
 
+    auto memorySensor = new ProcessSensor<qlonglong>(this,
+                                                     QStringLiteral("memory"),
+                                                     i18nc("@title:column", "Memory Usage"),
+                                                     &KSysGuard::Process::memory,
+                                                     KSysGuard::Process::Memory);
+    memorySensor->setShortName(i18nc("@title:column", "Memory"));
+    memorySensor->setUnit(KSysGuard::UnitKiloByte);
+    memorySensor->setMin(0);
+    memorySensor->setMax(totalPhysicalMemory());
+    memorySensor->setRequiredUpdateFlags(Processes::Smaps);
+    memorySensor->setDescription(
+        i18nc("@info:tooltip",
+              "This is an approximation of the real amount of physical memory that this process is using. It will use the Proportional Memory Usage if "
+              "available, the Private Memory Usage if that has a value, and the Resident Memory Usage otherwise."));
+    d->m_coreAttributes << memorySensor;
+
+    auto swapSensor =
+        new ProcessSensor<qlonglong>(this, QStringLiteral("swap"), i18nc("@title:column", "Swap Usage"), &KSysGuard::Process::swap, KSysGuard::Process::Memory);
+    swapSensor->setShortName(i18nc("@title:column", "Swap"));
+    swapSensor->setUnit(KSysGuard::UnitKiloByte);
+    swapSensor->setMin(0);
+    swapSensor->setMax(totalSwapMemory());
+    swapSensor->setDescription(i18nc("@info:tooltip", "This is an approximation of the amount of swap memory this process is using."));
+    d->m_coreAttributes << memorySensor;
+
     auto nameSensor =
         new ProcessSensor<QString>(this, QStringLiteral("name"), i18n("Name"), &KSysGuard::Process::name, KSysGuard::Process::Name, ForwardFirstEntry);
     nameSensor->setDescription(i18n("The process name."));
