@@ -1,38 +1,25 @@
 /*
-    Copyright (C) 2020 Marco Martin <mart@kde.org>
+    SPDX-FileCopyrightText: 2020 Marco Martin <mart@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "SensorGroup_p.h"
 
-#include <QRegularExpression>
-#include <QDebug>
 #include <KLocalizedString>
+#include <QDebug>
+#include <QRegularExpression>
 
 namespace KSysGuard
 {
-
 SensorGroup::SensorGroup()
 {
     retranslate();
 }
 
 SensorGroup::~SensorGroup()
-{}
+{
+}
 
 void SensorGroup::retranslate()
 {
@@ -57,8 +44,10 @@ void SensorGroup::retranslate()
     m_sensorNames[QStringLiteral("network/(?!all).*/ipv6address")] = i18n("[Group] IPv6 Address");
     m_sensorNames[QStringLiteral("network/(?!all).*/signal")] = i18n("[Group] Signal Strength");
     m_sensorNames[QStringLiteral("network/(?!all).*/download")] = i18n("[Group] Download Rate");
+    m_sensorNames[QStringLiteral("network/(?!all).*/downloadBits")] = i18n("[Group] Download Rate");
     m_sensorNames[QStringLiteral("network/(?!all).*/totalDownload")] = i18n("[Group] Total Downloaded");
     m_sensorNames[QStringLiteral("network/(?!all).*/upload")] = i18n("[Group] Upload Rate");
+    m_sensorNames[QStringLiteral("network/(?!all).*/uploadBits")] = i18n("[Group] Upload Rate");
     m_sensorNames[QStringLiteral("network/(?!all).*/totalUpload")] = i18n("[Group] Total Uploaded");
 
     m_sensorNames[QStringLiteral("disk/(?!all).*/name")] = i18n("[Group] Name");
@@ -77,7 +66,6 @@ void SensorGroup::retranslate()
 
 QString SensorGroup::groupRegexForId(const QString &key)
 {
-
     QRegularExpression cpuExpr(QStringLiteral("cpu/cpu\\d+/(.*)"));
     QRegularExpression netExpr(QStringLiteral("network/(?!all).*/(.*)$"));
     QRegularExpression partitionsExpr(QStringLiteral("partitions/(?!all).*/(.*)$"));
